﻿/*
 *
 *
 *    SimulatorControls.cs
 *
 *    Provides test classes for the application.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2014 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *    
 *
 */

using System;
using System.Windows.Forms;

namespace KK5JY.AutoCap {
	/// <summary>
	/// Controls for manipulating the simulator.
	/// </summary>
	public partial class SimulatorControls : Form {
		#region Private Fields
		private TestHardware m_Simulator;
		private Timer m_Timer;
		#endregion

		#region Public Methods
		public SimulatorControls(TestHardware sim) {
			InitializeComponent();

			m_Simulator = sim;
			numAntennaFrequency.Value = m_Simulator.AntennaFrequency;
			numAntennaBandwidth.Value = m_Simulator.AntennaBandwidth;
			numAntennaBandwidthEdgeSWR.Value = m_Simulator.AntennaEdgeSWR;
			numMotorRate.Value = m_Simulator.HzPerCycle;
			numTransmitterFrequency.Value = m_Simulator.CarrierFrequency;
			numTransmitterPower.Value = m_Simulator.CarrierPower;
			numAntennaCenter.Value = m_Simulator.AntennaCenterFrequency;

			m_Timer = new Timer();
			m_Timer.Interval = 100;
			m_Timer.Tick += new EventHandler(m_Timer_Tick);
		}
		#endregion

		#region Event Handlers
		private void m_Timer_Tick(object sender, EventArgs e) {
			numAntennaFrequency.Value = m_Simulator.AntennaFrequency;
		}

		protected override void OnShown(EventArgs e) {
			m_Timer.Enabled = true;
			base.OnShown(e);
		}

		protected override void OnClosing(System.ComponentModel.CancelEventArgs e) {
			m_Timer.Enabled = false;
			base.OnClosing(e);
		}

		private void numAntennaBandwidth_ValueChanged(object sender, EventArgs e) {
			m_Simulator.AntennaBandwidth = numAntennaBandwidth.Value;
		}

		private void numAntennaBandwidthEdgeSWR_ValueChanged(object sender, EventArgs e) {
			m_Simulator.AntennaEdgeSWR = numAntennaBandwidthEdgeSWR.Value;
		}

		private void numMotorRate_ValueChanged(object sender, EventArgs e) {
			m_Simulator.HzPerCycle = numMotorRate.Value;
		}

		private void numTransmitterFrequency_ValueChanged(object sender, EventArgs e) {
			m_Simulator.CarrierFrequency = numTransmitterFrequency.Value;
		}

		private void TransmitterPowerChanged(object sender, EventArgs e) {
			m_Simulator.CarrierPower = cbTX.Checked ? numTransmitterPower.Value : 0m;
		}

		private void cbTX_CheckedChanged(object sender, EventArgs e) {
			m_Simulator.CarrierPower = cbTX.Checked ? numTransmitterPower.Value : 0m;
		}

		private void numAntennaCenterChanged(object sender, EventArgs e) {
			m_Simulator.AntennaCenterFrequency = numAntennaCenter.Value;
		}
		#endregion
	}
}
